summaryrefslogtreecommitdiffstats
path: root/kfile-plugins/torrent/bytetape.h
diff options
context:
space:
mode:
Diffstat (limited to 'kfile-plugins/torrent/bytetape.h')
-rw-r--r--kfile-plugins/torrent/bytetape.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kfile-plugins/torrent/bytetape.h b/kfile-plugins/torrent/bytetape.h
index 55fef4b5..4c803122 100644
--- a/kfile-plugins/torrent/bytetape.h
+++ b/kfile-plugins/torrent/bytetape.h
@@ -21,7 +21,7 @@
#include <ksharedptr.h>
-#include <qcstring.h>
+#include <tqcstring.h>
class ByteTapeShared : public KShared
{
@@ -31,7 +31,7 @@ class ByteTapeShared : public KShared
};
/**
* Class to simulate a seekable byte stream. Very similar to QByteArray,
* but the difference is that this class "knows" what a current position
* is. Also, the copy constructor will share the byte stream of the
* ByteTape being copied. This means that any copies made of an object of
@@ -54,7 +54,7 @@ class ByteTape
* @param pos the initial position of the tape head. It must be
* a position within the buffer contained in @p array.
*/
- ByteTape (QByteArray &array, int pos = 0);
+ ByteTape (TQByteArray &array, int pos = 0);
/**
* Creates a ByteTape as a copy of @p tape. The newly created
@@ -177,15 +177,15 @@ class ByteTape
bool setPos(unsigned int pos);
/**
* Returns a reference to the QByteArray used to hold all the data.
*
* @return the QByteArray used to hold the data
* @see QByteArray
*/
- QByteArray &data() { return m_array; }
+ TQByteArray &data() { return m_array; }
private:
- QByteArray &m_array;
+ TQByteArray &m_array;
KSharedPtr<ByteTapeShared> m_shared;
};
@@ -31,7 +31,7 @@ class ByteTapeShared : public KShared
};
/**
- * Class to simulate a seekable byte stream. Very similar to QByteArray,
+ * Class to simulate a seekable byte stream. Very similar to TQByteArray,
* but the difference is that this class "knows" what a current position
* is. Also, the copy constructor will share the byte stream of the
@@ -177,15 +177,15 @@ class ByteTape
bool setPos(unsigned int pos);
/**
- * Returns a reference to the QByteArray used to hold all the data.
+ * Returns a reference to the TQByteArray used to hold all the data.
*
@@ -177,15 +177,15 @@ class ByteTape
*
- * @return the QByteArray used to hold the data
+ * @return the TQByteArray used to hold the data
* @see QByteArray
*/